try:
    from PIL import Image
except ImportError:
    import Image

import os, sys

def combine_stripes_images():
    img_vert_bw_stripes_0 = Image.open('vert_bw_stripes_0.jpg').convert('RGB')
    img_vert_bw_stripes_1 = Image.open('vert_bw_stripes_1.jpg').convert('RGB')
    img_horiz_bw_stripes_0 = Image.open('horiz_bw_stripes_0.jpg').convert('RGB')
    img_horiz_bw_stripes_1 = Image.open('horiz_bw_stripes_1.jpg').convert('RGB')

    img_black_vert = Image.new('RGB', (1080, 1080), color='black')
    img_white_vert = Image.new('RGB', (1080, 1080), color='white')
    img_black_horiz = Image.new('RGB', (1080, 1080), color='black')
    img_white_horiz = Image.new('RGB', (1080, 1080), color='white')

    vert_stripes_0 = img_vert_bw_stripes_0.load()
    vert_stripes_1 = img_vert_bw_stripes_1.load()
    horiz_stripes_0 = img_horiz_bw_stripes_0.load()
    horiz_stripes_1 = img_horiz_bw_stripes_1.load()

    white_vert = img_white_vert.load()
    black_vert = img_black_vert.load()
    white_horiz = img_white_horiz.load()
    black_horiz = img_black_horiz.load()

    assert (img_vert_bw_stripes_0.size == img_vert_bw_stripes_1.size == (1080, 1080))
    assert (img_horiz_bw_stripes_0.size == img_horiz_bw_stripes_1.size == (1080, 1080))

    for i in range(1080):
        for j in range(1080):
            if i % 2 == 0:
                black_vert[i, j] = vert_stripes_0[i, j]
                white_vert[i, j] = vert_stripes_1[i, j]

                black_horiz[j, i] = horiz_stripes_0[j, i]
                white_horiz[j, i] = horiz_stripes_1[j, i]
            else:
                black_vert[i, j] = vert_stripes_1[i, j]
                white_vert[i, j] = vert_stripes_0[i, j]

                black_horiz[j, i] = horiz_stripes_1[j, i]
                white_horiz[j, i] = horiz_stripes_0[j, i]

    img_black_vert.save("vert_stripes_black.jpg")
    img_white_vert.save("vert_stripes_white.jpg")

    img_black_horiz.save("horiz_stripes_black.jpg")
    img_white_horiz.save("horiz_stripes_white.jpg")

    print("Vertical and horizontal image duplicates combined")


def combine_alternating_images():
    img_alternating_0 = Image.open('bw_alternating_0.jpg').convert('RGB')
    img_alternating_1 = Image.open('bw_alternating_1.jpg').convert('RGB')
    img_black_alt = Image.new('RGB', (1080, 1080), color='black')
    img_white_alt = Image.new('RGB', (1080, 1080), color='white')

    alternating_0 = img_alternating_0.load()
    alternating_1 = img_alternating_1.load()
    black_alt = img_black_alt.load()
    white_alt = img_white_alt.load()

    assert (img_alternating_0.size == img_alternating_1.size == (1080, 1080))

    for i in range(1080):
        for j in range(1080):
            if (i + j) % 2 == 0:
                white_alt[i, j] = alternating_0[i, j]
                black_alt[i, j] = alternating_1[i, j]
            else:
                white_alt[i, j] = alternating_1[i, j]
                black_alt[i, j] = alternating_0[i, j]

    img_white_alt.save("alternating_white.jpg")
    img_black_alt.save("alternating_black.jpg")

    print("Alternating image duplicates combined")
